@@ -171,7 +171,7 @@ class Bitpin:
                     return
                 r_json: t.Dict = response.json()
             except Exception as e:
-                raise JSONDecodingError(func_name, e, additional)
+                raise JSONDecodingError(func_name, e, response=response, additional=additional)
 
         else:
             raise StatusCodeError(
@@ -179,6 +179,7 @@ class Bitpin:
                 f'invalid status code',
                 url=response.url,
                 status_code=response.status_code,
+                response=response,
                 additional=additional
             )
 
@@ -657,16 +658,19 @@ class Bitpin:
         f_name = cf().f_code.co_name
         f_args = self.__get_func_args(locals())
 
-        url = '/v1/odr/matches'
+        url = '/v1/odr/matches/'
+
+        params = None
 
         if page is not None:
-            url += f'?page={page}'
+            params = {'page': page}
 
         response = self._request(
             f_name,
             'GET',
             url,
             auth=True,
+            params=params
         )
 
         processed_response = self._process_response(f_name, response, f_args)
@@ -729,14 +733,17 @@ class Bitpin:
 
         url = '/v1/odr/orders/?state=active,initial'
 
+        params = None
+
         if page is not None:
-            url += f'?page={page}'
+            params = {'page': page}
 
         response = self._request(
             f_name,
             'GET',
             url,
             auth=True,
+            params=params,
         )
 
         processed_response = self._process_response(f_name, response, f_args)
